@@ -96,12 +96,22 @@ void DiffTextWindow::init(
    update();
 }
 
+void DiffTextWindow::reset()
+{
+   m_pLineData=0;
+   m_size=0;
+   m_pDiff3LineVector=0;
+   m_filename="";
+   m_diff3WrapLineVector.clear();
+}
+
 void DiffTextWindow::setPaintingAllowed( bool bAllowPainting )
 {
    if (m_bPaintingAllowed != bAllowPainting)
    {
       m_bPaintingAllowed = bAllowPainting;
       if ( m_bPaintingAllowed ) update();
+      else reset();
    }
 }
 
