@@ -121,6 +121,15 @@ void MergeResultWindow::init(
          .arg(getNrOfUnsolvedConflicts(&wsc)).arg(wsc) );
 }
 
+void MergeResultWindow::reset()
+{
+   m_pDiff3LineList = 0;
+   m_pTotalDiffStatus = 0;
+   m_pldA = 0;
+   m_pldB = 0;
+   m_pldC = 0;
+   m_fileName = "";
+}
 
 // Calculate the merge information for the given Diff3Line.
 // Results will be stored in mergeDetails, bConflict, bLineRemoved and src.
@@ -1155,7 +1164,10 @@ void MergeResultWindow::setPaintingAllowed(bool bPaintingAllowed)
 {
    m_bPaintingAllowed = bPaintingAllowed;
    if ( !m_bPaintingAllowed )
+   {
       m_currentMergeLineIt = m_mergeLineList.end();
+      reset();
+   }
 }
 
 void MergeResultWindow::paintEvent( QPaintEvent* e )
@@ -2037,7 +2049,8 @@ void MergeResultWindow::pasteClipboard( bool bFromSelection )
    QString currentLine = str.left(x);
    QString endOfLine = str.mid(x);
    int i;
-   for( i=0; i<(int)clipBoard.length(); ++i )
+   int len = clipBoard.length();
+   for( i=0; i<len; ++i )
    {
       QChar c = clipBoard[i];
       if ( c == '\r' ) continue;
@@ -2217,6 +2230,11 @@ void Overview::init( Diff3LineList* pDiff3LineList, bool bTripleDiff )
    update();
 }
 
+void Overview::reset()
+{
+   m_pDiff3LineList = 0;
+}
+
 void Overview::slotRedraw()
 {
    m_pixmap.resize( QSize(0,0) );   // make sure that a redraw happens
@@ -2265,6 +2283,7 @@ void Overview::setPaintingAllowed( bool bAllowPainting )
    {
       m_bPaintingAllowed = bAllowPainting;
       if ( m_bPaintingAllowed ) update();
+      else reset();
    }
 }
 
