@@ -521,7 +521,7 @@ void OptionDialog::setupColorPage( void )
 
 void OptionDialog::setupEditPage( void )
 {
-   QFrame *page = addPage( i18n("Editor"), i18n("Editor Behaviour"),
+   QFrame *page = addPage( i18n("Editor"), i18n("Editor Behavior"),
                            BarIcon("edit", KIcon::SizeMedium ) );
    QVBoxLayout *topLayout = new QVBoxLayout( page, 0, spacingHint() );
 
@@ -559,7 +559,7 @@ void OptionDialog::setupEditPage( void )
       ));
    ++line;
    
-   label = new QLabel( i18n("Line End Style:"), page );
+   label = new QLabel( i18n("Line end style:"), page );
    gbox->addWidget( label, line, 0 );
    #ifdef _WIN32
    int defaultLineEndStyle = eLineEndDos;
@@ -571,8 +571,8 @@ void OptionDialog::setupEditPage( void )
    pLineEndStyle->insertItem( "Unix", eLineEndUnix );
    pLineEndStyle->insertItem( "Dos/Windows", eLineEndDos );
    QToolTip::add( label, i18n(
-      "Sets the line endings for when a edited file is saved.\n"
-      "DOS/Windows: CR+LF; Unix: LF; with CR=0D, LF=0A")
+      "Sets the line endings for when an edited file is saved.\n"
+      "DOS/Windows: CR+LF; UNIX: LF; with CR=0D, LF=0A")
       );
    ++line;
       
@@ -608,7 +608,7 @@ void OptionDialog::setupDiffPage( void )
       );
    ++line;
 
-   OptionCheckBox* pIgnoreComments = new OptionCheckBox( i18n("Ignore C/C++ Comments"), false, "IgnoreComments", &m_bIgnoreComments, page, this );
+   OptionCheckBox* pIgnoreComments = new OptionCheckBox( i18n("Ignore C/C++ comments"), false, "IgnoreComments", &m_bIgnoreComments, page, this );
    gbox->addMultiCellWidget( pIgnoreComments, line, line, 0, 1 );
    QToolTip::add( pIgnoreComments, i18n( "Treat C/C++ comments like white space.")
       );
@@ -657,7 +657,7 @@ void OptionDialog::setupDiffPage( void )
    gbox->addWidget( label, line, 0 );
    OptionComboBox* pWhiteSpace2FileMergeDefault = new OptionComboBox( 0, "WhiteSpace2FileMergeDefault", &m_whiteSpace2FileMergeDefault, page, this );
    gbox->addWidget( pWhiteSpace2FileMergeDefault, line, 1 );
-   pWhiteSpace2FileMergeDefault->insertItem( i18n("Manual choice"), 0 );
+   pWhiteSpace2FileMergeDefault->insertItem( i18n("Manual Choice"), 0 );
    pWhiteSpace2FileMergeDefault->insertItem( "A", 1 );
    pWhiteSpace2FileMergeDefault->insertItem( "B", 2 );
    QToolTip::add( label, i18n(
@@ -670,7 +670,7 @@ void OptionDialog::setupDiffPage( void )
    gbox->addWidget( label, line, 0 );
    OptionComboBox* pWhiteSpace3FileMergeDefault = new OptionComboBox( 0, "WhiteSpace3FileMergeDefault", &m_whiteSpace3FileMergeDefault, page, this );
    gbox->addWidget( pWhiteSpace3FileMergeDefault, line, 1 );
-   pWhiteSpace3FileMergeDefault->insertItem( i18n("Manual choice"), 0 );
+   pWhiteSpace3FileMergeDefault->insertItem( i18n("Manual Choice"), 0 );
    pWhiteSpace3FileMergeDefault->insertItem( "A", 1 );
    pWhiteSpace3FileMergeDefault->insertItem( "B", 2 );
    pWhiteSpace3FileMergeDefault->insertItem( "C", 3 );
@@ -773,10 +773,10 @@ void OptionDialog::setupDirectoryMergePage( void )
    gbox->addMultiCellWidget( pBG, line, line, 0, 1 );
    ++line;
    
-   OptionRadioButton* pBinaryComparison = new OptionRadioButton( i18n("Binary Comparison"), true, "BinaryComparison", &m_bDmBinaryComparison, pBG, this );
+   OptionRadioButton* pBinaryComparison = new OptionRadioButton( i18n("Binary comparison"), true, "BinaryComparison", &m_bDmBinaryComparison, pBG, this );
    QToolTip::add( pBinaryComparison, i18n("Binary comparison of each file. (Default)") );
    
-   OptionRadioButton* pFullAnalysis = new OptionRadioButton( i18n("Full Analysis"), false, "FullAnalysis", &m_bDmFullAnalysis, pBG, this );
+   OptionRadioButton* pFullAnalysis = new OptionRadioButton( i18n("Full analysis"), false, "FullAnalysis", &m_bDmFullAnalysis, pBG, this );
    QToolTip::add( pFullAnalysis, i18n("Do a full analysis and show statistics information in extra columns.\n"
                                       "(Slower than a binary comparison, much slower for binary files.)") );
    
@@ -995,7 +995,7 @@ static char* countryMap[]={
                   ) );
    ++line;
 
-   label = new QLabel( i18n("Note: Local Encoding is ") + QTextCodec::codecForLocale()->name(), page );
+   label = new QLabel( i18n("Note: Local Encoding is ") + "\"" + QTextCodec::codecForLocale()->name() + "\"", page );
    gbox->addWidget( label, line, 0 );
    ++line;
 
